import setuptools

setuptools.setup(
    name="BanglaAI",
    version="0.0.1",
    author="Md Rashad Al Hasan Rony",
    author_email="banglaai.org@gmail.com",
    description= "Build Bangla AI powered Bengali Applications",
    url="https://www.banglaai.org/tools/banglaai",
    license="Apache License 2.0",
    packages=["banglaai"]
)